@@ -51,7 +51,7 @@
 #' or \code{c(max(kerncentre) - 5*lambda, max(kerncentre) + 5*lambda)} for normal kernel.
 #' Outside of this range the quantiles are set to \code{-Inf} for lower tail and \code{Inf}
 #' for upper tail. A sequence of values
-#' of length fifty times the number of kernels (upto a maximum of 1000) is first
+#' of length fifty times the number of kernels (with minimum of 1000) is first
 #' calculated. Spline based interpolation using \code{\link[stats:splinefun]{splinefun}},
 #' with default \code{monoH.FC} method, is then used to approximate the quantile
 #' function. This is a similar approach to that taken
@@ -67,7 +67,7 @@
 #' \code{\link[evmix:kden]{qkden}} gives the quantile function and 
 #' \code{\link[evmix:kden]{rkden}} gives a random sample.
 #' 
-#' @note Unlike all the other extreme value mixture model functions the 
+#' @note Unlike most of the other extreme value mixture model functions the 
 #'   \code{\link[evmix:kden]{kden}} functions have not been vectorised as
 #'   this is not appropriate. The main inputs (\code{x}, \code{p} or \code{q})
 #'   must be either a scalar or a vector, which also define the output length.
@@ -108,9 +108,11 @@
 #' 
 #' Wand, M. and Jones, M.C. (1995). Kernel Smoothing. Chapman && Hall.
 #' 
-#' @author Yang Hu and Carl Scarrott \email{carl.scarrott@@canterbury.ac.nz}. Based on code
-#' by Anna MacDonald produced for MATLAB.
+#' @author Yang Hu and Carl Scarrott \email{carl.scarrott@@canterbury.ac.nz}.
 #'
+#' @section Acknowledgments: Based on code
+#' by Anna MacDonald produced for MATLAB.
+#' 
 #' @seealso \code{\link[evmix:kernels]{kernels}}, \code{\link[evmix:kfun]{kfun}},
 #' \code{\link[stats:density]{density}}, \code{\link[stats:bandwidth]{bw.nrd0}}
 #' and \code{\link[ks:kde.1d]{dkde}} in \code{\link[ks:kde.1d]{ks}} package.
@@ -121,7 +123,9 @@
 #' 
 #' @examples
 #' \dontrun{
-#' par(mfrow=c(2,2))
+#' set.seed(1)
+#' par(mfrow = c(2, 2))
+#' 
 #' nk=50
 #' x = rnorm(nk)
 #' xx = seq(-5, 5, 0.01)
@@ -177,11 +181,11 @@ NULL
 dkden <- function(x, kerncentres, lambda = NULL, bw = NULL, kernel = "gaussian", log = FALSE) {
 
   # Check properties of inputs
-  check.quant(x, allowmiss = TRUE, allowinf = TRUE)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.quant(x, allowna = TRUE, allowinf = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw, allownull = TRUE)
   check.kernel(kernel)
-  check.logic(logicarg = log)
+  check.logic(log)
 
   kernel = ifelse(kernel == "rectangular", "uniform", kernel)
   kernel = ifelse(kernel == "normal", "gaussian", kernel)
@@ -226,11 +230,11 @@ dkden <- function(x, kerncentres, lambda = NULL, bw = NULL, kernel = "gaussian",
 pkden <- function(q, kerncentres, lambda = NULL, bw = NULL, kernel = "gaussian", lower.tail = TRUE) {
 
   # Check properties of inputs
-  check.quant(q, allowmiss = TRUE, allowinf = TRUE)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.quant(q, allowna = TRUE, allowinf = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw, allownull = TRUE)
   check.kernel(kernel)
-  check.logic(logicarg = lower.tail)
+  check.logic(lower.tail)
 
   kernel = ifelse(kernel == "rectangular", "uniform", kernel)
   kernel = ifelse(kernel == "normal", "gaussian", kernel)
@@ -278,11 +282,11 @@ pkden <- function(q, kerncentres, lambda = NULL, bw = NULL, kernel = "gaussian",
 qkden <- function(p, kerncentres, lambda = NULL, bw = NULL, kernel = "gaussian", lower.tail = TRUE) {
 
   # Check properties of inputs
-  check.prob(p, allowmiss = TRUE)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.prob(p, allowna = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw, allownull = TRUE)
   check.kernel(kernel)
-  check.logic(logicarg = lower.tail)
+  check.logic(lower.tail)
 
   kernel = ifelse(kernel == "rectangular", "uniform", kernel)
   kernel = ifelse(kernel == "normal", "gaussian", kernel)
@@ -346,29 +350,10 @@ rkden <- function(n = 1, kerncentres, lambda = NULL, bw = NULL, kernel = "gaussi
 
   # Check properties of inputs
   check.n(n)
-  check.quant(kerncentres, allowmiss = TRUE, allowinf = TRUE)
+  check.quant(kerncentres, allowna = TRUE, allowinf = TRUE)
   check.kbw(lambda, bw, allownull = TRUE)
   check.kernel(kernel)
 
-  kernel = ifelse(kernel == "rectangular", "uniform", kernel)
-  kernel = ifelse(kernel == "normal", "gaussian", kernel)
-
-  if (any(!is.finite(kerncentres))) warning("non-finite kernel centres are dropped")
-
-  kerncentres = kerncentres[is.finite(kerncentres)]
-  check.quant(kerncentres)
-  nk = length(kerncentres)
-
-  if (is.null(lambda) & is.null(bw)) {
-    if (nk == 1) {
-      stop("Automated bandwidth estimation requires 2 or more kernel centres")
-    } else if (nk < 10) {
-      warning("Automated bandwidth estimation unreliable with less than 10 kernel centres")
-    }
-    bw = bw.nrd0(kerncentres)
-  }
-  lambda = klambda(bw, kernel, lambda)
-  
   # Inversion sampling (very inefficient!, but avoids need for RNG's for all different kernels)
-  qkden(runif(n), kerncentres, lambda,, kernel = kernel)
+  qkden(runif(n), kerncentres, lambda, bw, kernel)
 }
