@@ -381,7 +381,7 @@ lgammagpd <- function(x, gshape = 1, gscale = 1, u = qgamma(0.9, gshape, 1/gscal
   
     syu = 1 + xi * (xu - u) / sigmau  
   
-    if ((min(syu) <= 0) | (phiu <= 0) | (phiu >= 1)) {
+    if ((min(syu) <= 0) | (phiu <= 0) | (phiu >= 1) | (pu <= 0) | (pu >= 1)) {
       l = -Inf
     } else { 
       l = lgpd(xu, u, sigmau, xi, phiu)
@@ -433,7 +433,7 @@ nlgammagpd <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 # gamma bulk with GPD for upper tail
 # designed for sapply to loop over vector of thresholds (hence u is first input)
 proflugammagpd <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
-  control = list(maxit = 10000), finitelik = FALSE, ...) {
+  control = list(maxit = 10000), finitelik = TRUE, ...) {
 
   np = 5 # maximum number of parameters
 
