@@ -428,7 +428,7 @@ nlitmnormgpd <- function(pvector, x, finitelik = FALSE) {
 # designed for sapply to loop over matrix with two columns vector of threshold and epsilon pairs
 # (hence eu is first input)
 profleuitmnormgpd <- function(eu, pvector, x, method = "BFGS",
-  control = list(maxit = 10000), finitelik = FALSE, ...) {
+  control = list(maxit = 10000), finitelik = TRUE, ...) {
 
   np = 6 # maximum number of parameters
 
