@@ -257,7 +257,12 @@ fmgammagpd <- function(x, M, phiu = TRUE, useq = NULL, fixedu = FALSE, pvector =
   check.quant(x)
   n = length(x)
 
-  if (is.unsorted(x)) x = sort(x)
+  if (is.unsorted(x)) {
+    x = sort(x)
+  } else {
+    if (x[1] > x[length(x)])
+      x = rev(x)
+  }
 
   if ((method == "L-BFGS-B") | (method == "BFGS")) finitelik = TRUE
   
@@ -702,7 +707,7 @@ lmgammagpd <- function(x, mgshape, mgscale, mgweight, u, sigmau, xi, phiu = TRUE
     
     syu = 1 + xi * (xu - u)/sigmau
 
-    if ((min(syu) <= 0) | (phiu <= 0) | (phiu >= 1)) {
+    if ((min(syu) <= 0) | (phiu <= 0) | (phiu >= 1) | (pu <= 0) | (pu >= 1)) {
       l = -Inf
     }
     else {
@@ -879,7 +884,7 @@ nlEMmgammagpd <- function(pvector, tau, mgweight, x, M, phiu = TRUE, finitelik =
 # mixture of gammas bulk with GPD for upper tail, using EM algorithm
 # designed for sapply to loop over vector of thresholds (hence u is first input)
 proflumgammagpd <- function(u, pvector, x, M, phiu = TRUE,
-  method = "BFGS", control = list(maxit = 10000), finitelik = FALSE, ...) {
+  method = "BFGS", control = list(maxit = 10000), finitelik = TRUE, ...) {
 
   check.n(M)
   if (M == 1) stop("use proflugammagpd instead")
@@ -909,7 +914,12 @@ proflumgammagpd <- function(u, pvector, x, M, phiu = TRUE,
   check.quant(x)
   n = length(x)
 
-  if (is.unsorted(x)) x = sort(x)
+  if (is.unsorted(x)) {
+    x = sort(x)
+  } else {
+    if (x[1] > x[length(x)])
+      x = rev(x)
+  }
 
   # approximate MLE for each gamma component
   approxmle = function(x) {
